@@ -2,6 +2,7 @@ from __future__ import absolute_import, unicode_literals
 
 import uuid
 from copy import copy
+from collections import defaultdict
 
 from django.conf.urls import patterns, url
 from django.db import connections
@@ -10,12 +11,12 @@ from django.utils.translation import ugettext_lazy as _, ungettext_lazy as __
 from debug_toolbar.panels import Panel
 from debug_toolbar.panels.sql.forms import SQLSelectForm
 from debug_toolbar.utils import render_stacktrace
-from debug_toolbar.panels.sql.utils import reformat_sql
+from debug_toolbar.panels.sql.utils import reformat_sql, contrasting_color_generator
 from debug_toolbar.panels.sql.tracking import wrap_cursor, unwrap_cursor
 
 
-def get_isolation_level_display(engine, level):
-    if engine == 'psycopg2':
+def get_isolation_level_display(vendor, level):
+    if vendor == 'postgresql':
         import psycopg2.extensions
         choices = {
             psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT: _("Autocommit"),
@@ -25,12 +26,12 @@ def get_isolation_level_display(engine, level):
             psycopg2.extensions.ISOLATION_LEVEL_SERIALIZABLE: _("Serializable"),
         }
     else:
-        raise ValueError(engine)
+        raise ValueError(vendor)
     return choices.get(level)
 
 
-def get_transaction_status_display(engine, level):
-    if engine == 'psycopg2':
+def get_transaction_status_display(vendor, level):
+    if vendor == 'postgresql':
         import psycopg2.extensions
         choices = {
             psycopg2.extensions.TRANSACTION_STATUS_IDLE: _("Idle"),
@@ -40,7 +41,7 @@ def get_transaction_status_display(engine, level):
             psycopg2.extensions.TRANSACTION_STATUS_UNKNOWN: _("Unknown"),
         }
     else:
-        raise ValueError(engine)
+        raise ValueError(vendor)
     return choices.get(level)
 
 
@@ -66,11 +67,10 @@ class SQLPanel(Panel):
         if not conn:
             return
 
-        engine = conn.__class__.__module__.split('.', 1)[0]
-        if engine == 'psycopg2':
+        if conn.vendor == 'postgresql':
             cur_status = conn.get_transaction_status()
         else:
-            raise ValueError(engine)
+            raise ValueError(conn.vendor)
 
         last_status = self._transaction_status.get(alias)
         self._transaction_status[alias] = cur_status
@@ -136,6 +136,8 @@ class SQLPanel(Panel):
             unwrap_cursor(connection)
 
     def process_response(self, request, response):
+        colors = contrasting_color_generator()
+        trace_colors = defaultdict(lambda: next(colors))
         if self._queries:
             width_ratio_tally = 0
             factor = int(256.0 / (len(self._databases) * 2.5))
@@ -172,10 +174,10 @@ class SQLPanel(Panel):
 
                 query['alias'] = alias
                 if 'iso_level' in query:
-                    query['iso_level'] = get_isolation_level_display(query['engine'],
+                    query['iso_level'] = get_isolation_level_display(query['vendor'],
                                                                      query['iso_level'])
                 if 'trans_status' in query:
-                    query['trans_status'] = get_transaction_status_display(query['engine'],
+                    query['trans_status'] = get_transaction_status_display(query['vendor'],
                                                                            query['trans_status'])
 
                 query['form'] = SQLSelectForm(auto_id=None, initial=copy(query))
@@ -196,6 +198,8 @@ class SQLPanel(Panel):
                 query['stacktrace'] = render_stacktrace(query['stacktrace'])
                 i += 1
 
+                query['trace_color'] = trace_colors[query['stacktrace']]
+
             if trans_id:
                 self._queries[(i - 1)][1]['ends_trans'] = True
 
