@@ -1,10 +1,4 @@
-(function (factory) {
-    if (typeof define === 'function' && define.amd) {
-        define(['jquery'], factory);
-    } else {
-        factory(jQuery);
-    }
-}(function ($) {
+(function ($) {
     function getSubcalls(row) {
         var id = row.attr('id');
         return $('.djDebugProfileRow[id^="'+id+'_"]');
@@ -23,5 +17,4 @@
             subcalls.hide();
         }
     });
-
-}));
+})(djdt.jQuery);
