@@ -1,13 +1,7 @@
-(function (factory) {
-    if (typeof define === 'function' && define.amd) {
-        define(['jquery'], factory);
-    } else {
-        factory(jQuery);
-    }
-}(function ($) {
+(function ($) {
     $('#djDebug a.djDebugToggle').on('click', function(e) {
         e.preventDefault();
         $(this).parent().find('.djDebugCollapsed').toggle();
         $(this).parent().find('.djDebugUncollapsed').toggle();
     });
-}));
+})(djdt.jQuery);
